package de.unirostock.Prototype.example.gui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;
import javax.swing.border.LineBorder;

import de.unirostock.Prototype.example.Ship;
import de.unirostock.Prototype.example.ShipFactory;



public class ShipInfoPanel extends javax.swing.JPanel
implements ActionListener
{
	private final static String	BT_GET	= "BT_GET";
	
	private	ShipFactory			itsFactory;
	private ShipInfoPanelModel	itsModel;
	
	private JLabel imgPhoto;
	private JLabel labShipType;
	private JLabel labShipName;
	private JLabel labShipMaterial;

	public ShipInfoPanel() {
		super();
		initGUI();
		itsFactory	= ShipFactory.getInstance();
	}
	
	public void setShipInfoPanelModel( ShipInfoPanelModel model ){
		itsModel	= model;
	}
	
	public void actionPerformed( ActionEvent e ){
		if( e.getActionCommand().equals( BT_GET )){
			if( itsModel == null ) return;
			updateInfo();
		}
		repaint();
	}
	
	private void updateInfo(){
		itsFactory.setShipPrototype( itsModel.getShipPrototype());
		Ship	ship	= itsFactory.getNewShipInstance( itsModel.getShipMaterial(), itsModel.getShipName());
		imgPhoto.setIcon( ship.getIcon());
		labShipType.setText( getShipCLassName( ship )+" / "+ship.getNumber());
		labShipMaterial.setText( ship.getMaterial());
		labShipName.setText( ship.getName());
	}
	
	private String getShipCLassName( Ship ship ){
		String	shipName	= ship.getClass().getName();
		int		lastDot	= shipName.lastIndexOf( '.' );
		return shipName.substring( lastDot+1 );
	}
	
	private void initGUI() {
		try {
			this.setPreferredSize(new java.awt.Dimension(250, 300));
			GridBagLayout thisLayout = new GridBagLayout();
			thisLayout.columnWeights = new double[] {0.1};
			thisLayout.columnWidths = new int[] {7};
			thisLayout.rowWeights = new double[] {0.1,0.1,0.1,0.1};
			thisLayout.rowHeights = new int[] {7,7,7,7};
			this.setLayout(thisLayout);
			this.setBackground(new java.awt.Color(250,248,238));
			{
				JPanel infoPanel = new JPanel();
				this.add(infoPanel, new GridBagConstraints(
					0,
					2,
					1,
					1,
					0.0,
					0.0,
					GridBagConstraints.NORTH,
					GridBagConstraints.NONE,
					new Insets(5, 0, 0, 0),
					0,
					0));
				infoPanel.setLayout(null);
				infoPanel.setPreferredSize(new java.awt.Dimension(250, 200));
				infoPanel.setBorder(new LineBorder(new java.awt.Color(0,0,0), 1, false));
				infoPanel.setBackground(new java.awt.Color(255,255,255));
				{
					JLabel labText1 = new JLabel();
					infoPanel.add(labText1);
					labText1.setText("Informationen ber die neue Instanz:");
					labText1.setBounds(22, 5, 206, 20);
				}
				{
					imgPhoto = new JLabel();
					infoPanel.add(imgPhoto);
					imgPhoto.setBounds(62, 35, 127, 82);
					imgPhoto.setBorder(new LineBorder(new java.awt.Color(0,0,0), 1, false));
					imgPhoto.setBackground(new java.awt.Color(200,200,200));
				}
				{
					JLabel labText2 = new JLabel();
					infoPanel.add(labText2);
					labText2.setText("Typ / Nr.:");
					labText2.setBounds(22, 130, 80, 20);
				}
				{
					labShipType = new JLabel();
					infoPanel.add(labShipType);
					labShipType.setBounds(108, 130, 120, 20);
					labShipType.setHorizontalAlignment(SwingConstants.RIGHT);
					labShipType.setFont(new java.awt.Font("Arial",0,12));
				}
				{
					JLabel labText3 = new JLabel();
					infoPanel.add(labText3);
					labText3.setText("Schiffsname:");
					labText3.setBounds(22, 150, 80, 20);
				}
				{
					labShipName = new JLabel();
					infoPanel.add(labShipName);
					labShipName.setBounds(108, 150, 120, 20);
					labShipName.setHorizontalAlignment(SwingConstants.RIGHT);
					labShipName.setFont(new java.awt.Font("Arial",0,12));
				}
				{
					JLabel labText4 = new JLabel();
					infoPanel.add(labText4);
					labText4.setText("Material:");
					labText4.setBounds(22, 170, 80, 20);
				}
				{
					labShipMaterial = new JLabel();
					infoPanel.add(labShipMaterial);
					labShipMaterial.setBounds(108, 170, 120, 20);
					labShipMaterial.setHorizontalAlignment(SwingConstants.RIGHT);
					labShipMaterial.setFont(new java.awt.Font("Arial",0,12));
				}
			}
			{
				JButton btGetInstance = new JButton();
				this.add(btGetInstance, new GridBagConstraints(
					0,
					1,
					1,
					1,
					0.0,
					0.0,
					GridBagConstraints.SOUTH,
					GridBagConstraints.NONE,
					new Insets(0, 0, 5, 0),
					0,
					0));
				btGetInstance.setText("factory.getInstance()");
				btGetInstance.setActionCommand( BT_GET );
				btGetInstance.addActionListener( this );
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
